@@ -19,7 +19,7 @@ from wsproto.events import (
 
 from .events import ws_socket_manage
 
-__version__ = '0.9.1'
+__version__ = '0.9.3'
 
 
 class WebSocket(object):
@@ -49,6 +49,9 @@ class WebSocket(object):
         self.rx_queue = Queue()
         self.tx_queue = UniversalQueue()
 
+        # buffer chunks
+        self.buffer = None
+
         # create detachable async context
         def detach(f):
             def wrap(*args):
@@ -82,7 +85,7 @@ class WebSocket(object):
     def close(self):
         self.tx_queue.put(CloseConnection(0))
         self.tx_queue.put(None)
-        while(self.readyState != WebSocket.CLOSED ):
+        while(self.readyState != WebSocket.CLOSED):
             time.sleep(1e-5)
 
     def join(self):
@@ -110,5 +113,14 @@ class WebSocket(object):
             self.onclose()
 
         # message
-        elif isinstance(message, str):
-            self.onmessage(message)
+        elif isinstance(message, tuple):
+            chunk, complete = message
+
+            if self.buffer is None:
+                self.buffer = chunk
+            else:
+                self.buffer += chunk
+
+            if complete:
+                self.onmessage(self.buffer)
+                self.buffer = None
